@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002, 2004-2011, 2016, 2022 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2024 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -98,21 +98,29 @@ struct conv_struct {
   /* Input (conversion multibyte -> unicode) */
   int iindex;
   struct mbtowc_funcs ifuncs;
+  unsigned int isurface;
+  state_t ibyteorder;
   state_t istate;
   /* Output (conversion unicode -> multibyte) */
   int oindex;
   struct wctomb_funcs ofuncs;
   int oflags;
+  unsigned int osurface;
   state_t ostate;
   /* Operation flags */
   int transliterate;
-  int discard_ilseq;
-  #ifndef LIBICONV_PLUG
+  unsigned int discard_ilseq;
   struct iconv_fallbacks fallbacks;
   struct iconv_hooks hooks;
-  #endif
 };
 
+/* The bits in discard_ilseq.  */
+/* Bit mask for discard invalid multibyte sequences in the input. */
+#define DISCARD_INVALID        2U
+/* Bit mask for discard characters that cannot be represented in the target
+   character set. */
+#define DISCARD_UNCONVERTIBLE  1U
+
 /*
  * Include all the converters.
  */
@@ -236,7 +244,8 @@ typedef struct {
 #include "euc_cn.h"
 #include "ces_gbk.h"
 #include "cp936.h"
-#include "gb18030.h"
+#include "gb18030_2005.h"
+#include "gb18030_2022.h"
 #include "iso2022_cn.h"
 #include "iso2022_cnext.h"
 #include "hz.h"
@@ -291,7 +300,36 @@ typedef struct {
 #endif
 
 #ifdef USE_ZOS
+
 #define DEDUPLICATE_TABLES 1
+
+/* Swaps the values 0x15 and 0x25.
+   Both gcc and clang compile this expression to something that involves as few
+   conditional branching instructions as possible. */
+#define swap_x15_x25_a(x) ((x) == 0x15 ? 0x25 : (x) == 0x25 ? 0x15 : (x))
+#define swap_x15_x25_b(x) ((x) ^ ((x) == 0x15 || (x) == 0x25 ? 0x30 : 0))
+#define swap_x15_x25_c(x) ((x) ^ ((((x) - 0x15) & ~0x10) == 0 ? 0x30 : 0))
+/* Number of conditional branches (with "gcc -O2", as of 2023):
+                   a    b    c
+                 ---------------
+   aarch64         1    0    0
+   alpha           0    0    0
+   arm             1    0    0
+   hppa            1    1    1
+   i686            1    0    0
+   m68k            2    1    1
+   mips            2    1    0
+   mips64          2    1    0
+   powerpc         2    1    1
+   powerpc64       2    1    1
+   powerpc64le     2    1    1
+   riscv64         2    1    1
+   s390x           1    1    1
+   sh4             2    1    1
+   x86_64          1    0    0
+*/
+#define swap_x15_x25 swap_x15_x25_c
+
 #include "ebcdic037.h"
 #include "ebcdic273.h"
 #include "ebcdic277.h"
