@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2008, 2011, 2016, 2018, 2020, 2022 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2024 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -236,10 +236,12 @@ iconv_t iconv_open (const char* tocode, const char* fromcode)
   struct conv_struct * cd;
   unsigned int from_index;
   int from_wchar;
+  unsigned int from_surface;
   unsigned int to_index;
   int to_wchar;
+  unsigned int to_surface;
   int transliterate;
-  int discard_ilseq;
+  unsigned int discard_ilseq;
 
 #include "iconv_open1.h"
 
@@ -279,14 +281,12 @@ int iconv_close (iconv_t icd)
   return 0;
 }
 
-#ifndef LIBICONV_PLUG
-
 /*
  * Verify that a 'struct conv_struct' and a 'struct wchar_conv_struct' each
  * fit in an iconv_allocation_t.
  * If this verification fails, iconv_allocation_t must be made larger and
  * the major version in LIBICONV_VERSION_INFO must be bumped.
- * Currently 'struct conv_struct' has 21 integer/pointer fields, and
+ * Currently 'struct conv_struct' has 23 integer/pointer fields, and
  * 'struct wchar_conv_struct' additionally has an 'mbstate_t' field.
  */
 typedef int verify_size_1[2 * (sizeof (struct conv_struct) <= sizeof (iconv_allocation_t)) - 1];
@@ -298,10 +298,12 @@ int iconv_open_into (const char* tocode, const char* fromcode,
   struct conv_struct * cd;
   unsigned int from_index;
   int from_wchar;
+  unsigned int from_surface;
   unsigned int to_index;
   int to_wchar;
+  unsigned int to_surface;
   int transliterate;
-  int discard_ilseq;
+  unsigned int discard_ilseq;
 
 #include "iconv_open1.h"
 
@@ -315,6 +317,9 @@ invalid:
   return -1;
 }
 
+/* Bit mask of all valid surfaces. */
+#define ALL_SURFACES (ICONV_SURFACE_EBCDIC_ZOS_UNIX)
+
 int iconvctl (iconv_t icd, int request, void* argument)
 {
   conv_t cd = (conv_t) icd;
@@ -322,7 +327,8 @@ int iconvctl (iconv_t icd, int request, void* argument)
     case ICONV_TRIVIALP:
       *(int *)argument =
         ((cd->lfuncs.loop_convert == unicode_loop_convert
-          && cd->iindex == cd->oindex)
+          && cd->iindex == cd->oindex
+          && cd->isurface == cd->osurface)
          || cd->lfuncs.loop_convert == wchar_id_loop_convert
          ? 1 : 0);
       return 0;
@@ -332,11 +338,33 @@ int iconvctl (iconv_t icd, int request, void* argument)
     case ICONV_SET_TRANSLITERATE:
       cd->transliterate = (*(const int *)argument ? 1 : 0);
       return 0;
+    case ICONV_GET_DISCARD_INVALID:
+      *(int *)argument = (cd->discard_ilseq & DISCARD_INVALID ? 1 : 0);
+      return 0;
+    case ICONV_SET_DISCARD_INVALID:
+      if (*(const int *)argument)
+        cd->discard_ilseq |= DISCARD_INVALID;
+      else
+        cd->discard_ilseq &= ~DISCARD_INVALID;
+      return 0;
+    case ICONV_GET_DISCARD_NON_IDENTICAL:
+      *(int *)argument = (cd->discard_ilseq & DISCARD_UNCONVERTIBLE ? 1 : 0);
+      return 0;
+    case ICONV_SET_DISCARD_NON_IDENTICAL:
+      if (*(const int *)argument)
+        cd->discard_ilseq |= DISCARD_UNCONVERTIBLE;
+      else
+        cd->discard_ilseq &= ~DISCARD_UNCONVERTIBLE;
+      return 0;
     case ICONV_GET_DISCARD_ILSEQ:
-      *(int *)argument = cd->discard_ilseq;
+      *(int *)argument =
+        ((DISCARD_INVALID | DISCARD_UNCONVERTIBLE) & ~ cd->discard_ilseq) == 0;
       return 0;
     case ICONV_SET_DISCARD_ILSEQ:
-      cd->discard_ilseq = (*(const int *)argument ? 1 : 0);
+      if (*(const int *)argument)
+        cd->discard_ilseq |= DISCARD_INVALID | DISCARD_UNCONVERTIBLE;
+      else
+        cd->discard_ilseq &= ~(DISCARD_INVALID | DISCARD_UNCONVERTIBLE);
       return 0;
     case ICONV_SET_HOOKS:
       if (argument != NULL) {
@@ -358,6 +386,28 @@ int iconvctl (iconv_t icd, int request, void* argument)
         cd->fallbacks.data = NULL;
       }
       return 0;
+    case ICONV_GET_FROM_SURFACE:
+      *(unsigned int *)argument = cd->isurface;
+      return 0;
+    case ICONV_SET_FROM_SURFACE:
+      if ((*(const unsigned int *)argument & ~ALL_SURFACES) == 0) {
+        cd->isurface = *(const unsigned int *)argument;
+        return 0;
+      } else {
+        errno = EINVAL;
+        return -1;
+      }
+    case ICONV_GET_TO_SURFACE:
+      *(unsigned int *)argument = cd->osurface;
+      return 0;
+    case ICONV_SET_TO_SURFACE:
+      if ((*(const unsigned int *)argument & ~ALL_SURFACES) == 0) {
+        cd->osurface = *(const unsigned int *)argument;
+        return 0;
+      } else {
+        errno = EINVAL;
+        return -1;
+      }
     default:
       errno = EINVAL;
       return -1;
@@ -625,5 +675,3 @@ strong_alias (libiconv_open, iconv_open)
 strong_alias (libiconv, iconv)
 strong_alias (libiconv_close, iconv_close)
 #endif
-
-#endif
