@@ -1,21 +1,20 @@
 /*
- * Copyright (C) 1999-2003, 2005-2006 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2024 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
- * and/or modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either version 2
+ * and/or modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either version 2.1
  * of the License, or (at your option) any later version.
  *
  * The GNU LIBICONV Library is distributed in the hope that it will be
  * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
- * If not, write to the Free Software Foundation, Inc., 51 Franklin Street,
- * Fifth Floor, Boston, MA 02110-1301, USA.
+ * If not, see <https://www.gnu.org/licenses/>.
  */
 
 /* This file defines the conversion loop via Unicode as a pivot encoding. */
@@ -154,8 +153,6 @@ static int unicode_transliterate (conv_t cd, ucs4_t wc,
   return RET_ILUNI;
 }
 
-#ifndef LIBICONV_PLUG
-
 struct uc_to_mb_fallback_locals {
   unsigned char* l_outbuf;
   size_t l_outbytesleft;
@@ -217,12 +214,10 @@ static void mb_to_uc_write_replacement (const unsigned int *buf, size_t buflen,
         if (outcount != RET_ILUNI)
           goto outcount_ok;
       }
-      if (cd->discard_ilseq) {
+      if (cd->discard_ilseq & DISCARD_UNCONVERTIBLE) {
         outcount = 0;
         goto outcount_ok;
-      }
-      #ifndef LIBICONV_PLUG
-      else if (cd->fallbacks.uc_to_mb_fallback != NULL) {
+      } else if (cd->fallbacks.uc_to_mb_fallback != NULL) {
         struct uc_to_mb_fallback_locals locals;
         locals.l_outbuf = outptr;
         locals.l_outbytesleft = outleft;
@@ -240,7 +235,6 @@ static void mb_to_uc_write_replacement (const unsigned int *buf, size_t buflen,
         outcount = 0;
         goto outcount_ok;
       }
-      #endif
       outcount = cd->ofuncs.xxx_wctomb(cd,outptr,0xFFFD,outleft);
       if (outcount != RET_ILUNI)
         goto outcount_ok;
@@ -251,10 +245,8 @@ static void mb_to_uc_write_replacement (const unsigned int *buf, size_t buflen,
         plocals->l_errno = E2BIG;
         break;
       }
-      #ifndef LIBICONV_PLUG
       if (cd->hooks.uc_hook)
         (*cd->hooks.uc_hook)(wc, cd->hooks.data);
-      #endif
       if (!(outcount <= outleft)) abort();
       outptr += outcount; outleft -= outcount;
     outcount_zero: ;
@@ -264,8 +256,6 @@ static void mb_to_uc_write_replacement (const unsigned int *buf, size_t buflen,
   }
 }
 
-#endif /* !LIBICONV_PLUG */
-
 static size_t unicode_loop_convert (iconv_t icd,
                                     const char* * inbuf, size_t *inbytesleft,
                                     char* * outbuf, size_t *outbytesleft)
@@ -283,57 +273,59 @@ static size_t unicode_loop_convert (iconv_t icd,
     int outcount;
     incount = cd->ifuncs.xxx_mbtowc(cd,&wc,inptr,inleft);
     if (incount < 0) {
-      if (incount == RET_ILSEQ) {
-        /* Case 1: invalid input */
-        if (cd->discard_ilseq) {
+      if ((unsigned int)(-1-incount) % 2 == (unsigned int)(-1-RET_ILSEQ) % 2) {
+        /* Case 1: invalid input, possibly after a shift sequence */
+        incount = DECODE_SHIFT_ILSEQ(incount);
+        if (cd->discard_ilseq & DISCARD_INVALID) {
           switch (cd->iindex) {
             case ei_ucs4: case ei_ucs4be: case ei_ucs4le:
             case ei_utf32: case ei_utf32be: case ei_utf32le:
             case ei_ucs4internal: case ei_ucs4swapped:
-              incount = 4; break;
+              incount += 4; break;
             case ei_ucs2: case ei_ucs2be: case ei_ucs2le:
             case ei_utf16: case ei_utf16be: case ei_utf16le:
             case ei_ucs2internal: case ei_ucs2swapped:
-              incount = 2; break;
+              incount += 2; break;
             default:
-              incount = 1; break;
+              incount += 1; break;
           }
           goto outcount_zero;
-        }
-        #ifndef LIBICONV_PLUG
-        else if (cd->fallbacks.mb_to_uc_fallback != NULL) {
+        } else if (cd->fallbacks.mb_to_uc_fallback != NULL) {
+          unsigned int incount2;
           struct mb_to_uc_fallback_locals locals;
           switch (cd->iindex) {
             case ei_ucs4: case ei_ucs4be: case ei_ucs4le:
             case ei_utf32: case ei_utf32be: case ei_utf32le:
             case ei_ucs4internal: case ei_ucs4swapped:
-              incount = 4; break;
+              incount2 = 4; break;
             case ei_ucs2: case ei_ucs2be: case ei_ucs2le:
             case ei_utf16: case ei_utf16be: case ei_utf16le:
             case ei_ucs2internal: case ei_ucs2swapped:
-              incount = 2; break;
+              incount2 = 2; break;
             default:
-              incount = 1; break;
+              incount2 = 1; break;
           }
           locals.l_cd = cd;
           locals.l_outbuf = outptr;
           locals.l_outbytesleft = outleft;
           locals.l_errno = 0;
-          cd->fallbacks.mb_to_uc_fallback(inptr, incount,
+          cd->fallbacks.mb_to_uc_fallback((const char*)inptr+incount, incount2,
                                           mb_to_uc_write_replacement,
                                           &locals,
                                           cd->fallbacks.data);
           if (locals.l_errno != 0) {
+            inptr += incount; inleft -= incount;
             errno = locals.l_errno;
             result = -1;
             break;
           }
+          incount += incount2;
           outptr = locals.l_outbuf;
           outleft = locals.l_outbytesleft;
           result += 1;
           goto outcount_zero;
         }
-        #endif
+        inptr += incount; inleft -= incount;
         errno = EILSEQ;
         result = -1;
         break;
@@ -345,7 +337,7 @@ static size_t unicode_loop_convert (iconv_t icd,
         break;
       }
       /* Case 3: k bytes read, but only a shift sequence */
-      incount = -2-incount;
+      incount = DECODE_TOOFEW(incount);
     } else {
       /* Case 4: k bytes read, making up a wide character */
       if (outleft == 0) {
@@ -367,12 +359,10 @@ static size_t unicode_loop_convert (iconv_t icd,
         if (outcount != RET_ILUNI)
           goto outcount_ok;
       }
-      if (cd->discard_ilseq) {
+      if (cd->discard_ilseq & DISCARD_UNCONVERTIBLE) {
         outcount = 0;
         goto outcount_ok;
-      }
-      #ifndef LIBICONV_PLUG
-      else if (cd->fallbacks.uc_to_mb_fallback != NULL) {
+      } else if (cd->fallbacks.uc_to_mb_fallback != NULL) {
         struct uc_to_mb_fallback_locals locals;
         locals.l_outbuf = outptr;
         locals.l_outbytesleft = outleft;
@@ -391,7 +381,6 @@ static size_t unicode_loop_convert (iconv_t icd,
         outcount = 0;
         goto outcount_ok;
       }
-      #endif
       outcount = cd->ofuncs.xxx_wctomb(cd,outptr,0xFFFD,outleft);
       if (outcount != RET_ILUNI)
         goto outcount_ok;
@@ -406,10 +395,8 @@ static size_t unicode_loop_convert (iconv_t icd,
         result = -1;
         break;
       }
-      #ifndef LIBICONV_PLUG
       if (cd->hooks.uc_hook)
         (*cd->hooks.uc_hook)(wc, cd->hooks.data);
-      #endif
       if (!(outcount <= outleft)) abort();
       outptr += outcount; outleft -= outcount;
     }
@@ -454,12 +441,10 @@ static size_t unicode_loop_reset (iconv_t icd,
           if (outcount != RET_ILUNI)
             goto outcount_ok;
         }
-        if (cd->discard_ilseq) {
+        if (cd->discard_ilseq & DISCARD_UNCONVERTIBLE) {
           outcount = 0;
           goto outcount_ok;
-        }
-        #ifndef LIBICONV_PLUG
-        else if (cd->fallbacks.uc_to_mb_fallback != NULL) {
+        } else if (cd->fallbacks.uc_to_mb_fallback != NULL) {
           struct uc_to_mb_fallback_locals locals;
           locals.l_outbuf = outptr;
           locals.l_outbytesleft = outleft;
@@ -478,7 +463,6 @@ static size_t unicode_loop_reset (iconv_t icd,
           outcount = 0;
           goto outcount_ok;
         }
-        #endif
         outcount = cd->ofuncs.xxx_wctomb(cd,outptr,0xFFFD,outleft);
         if (outcount != RET_ILUNI)
           goto outcount_ok;
@@ -491,10 +475,8 @@ static size_t unicode_loop_reset (iconv_t icd,
           errno = E2BIG;
           return -1;
         }
-        #ifndef LIBICONV_PLUG
         if (cd->hooks.uc_hook)
           (*cd->hooks.uc_hook)(wc, cd->hooks.data);
-        #endif
         if (!(outcount <= outleft)) abort();
         outptr += outcount;
         outleft -= outcount;
