@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1999-2001, 2008, 2011 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2024 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
- * and/or modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either version 2
+ * and/or modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either version 2.1
  * of the License, or (at your option) any later version.
  *
  * The GNU LIBICONV Library is distributed in the hope that it will be
  * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
- * If not, see <http://www.gnu.org/licenses/>.
+ * If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -31,37 +31,43 @@
    The default is big-endian. */
 /* The state is 0 if big-endian, 1 if little-endian. */
 static int
-utf32_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, int n)
+utf32_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
 {
-  state_t state = conv->istate;
+  state_t state = conv->ibyteorder;
   int count = 0;
-  for (; n >= 4;) {
+  for (; n >= 4 && count <= RET_COUNT_MAX && count <= INT_MAX-4;) {
     ucs4_t wc = (state
-                  ? s[0] + (s[1] << 8) + (s[2] << 16) + (s[3] << 24)
-                  : (s[0] << 24) + (s[1] << 16) + (s[2] << 8) + s[3]);
+                  ?    (ucs4_t) s[0]
+                    + ((ucs4_t) s[1] << 8)
+                    + ((ucs4_t) s[2] << 16)
+                    + ((ucs4_t) s[3] << 24)
+                  :   ((ucs4_t) s[0] << 24)
+                    + ((ucs4_t) s[1] << 16)
+                    + ((ucs4_t) s[2] << 8)
+                    +  (ucs4_t) s[3]);
     if (wc == 0x0000feff) {
     } else if (wc == 0xfffe0000u) {
       state ^= 1;
     } else {
       if (wc < 0x110000 && !(wc >= 0xd800 && wc < 0xe000)) {
         *pwc = wc;
-        conv->istate = state;
+        conv->ibyteorder = state;
         return count+4;
       } else {
-        conv->istate = state;
+        conv->ibyteorder = state;
         return RET_SHIFT_ILSEQ(count);
       }
     }
     s += 4; n -= 4; count += 4;
   }
-  conv->istate = state;
+  conv->ibyteorder = state;
   return RET_TOOFEW(count);
 }
 
 /* We output UTF-32 in big-endian order, with byte-order mark. */
 /* The state is 0 at the beginning, 1 after the BOM has been written. */
 static int
-utf32_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
+utf32_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
 {
   if (wc < 0x110000 && !(wc >= 0xd800 && wc < 0xe000)) {
     int count = 0;
